@@ -274,7 +274,12 @@ Status SetAuthentication(
 	umask (original_umask);
 
 	sprintf (command, "iceauth source %s", addAuthFile);
-	system(command);
+	{
+		int n;
+
+		n = system(command);
+		(void)n;
+	}
 
 	unlink (addAuthFile);
 
@@ -328,7 +333,12 @@ void FreeAuthenticationData(int count, FIceAuthDataEntry *authDataEntries)
 	free ((char *) authDataEntries);
 
 	sprintf (command, "iceauth source %s", remAuthFile);
-	system(command);
+	{
+		int n;
+
+		n = system(command);
+		(void)n;
+	}
 
 	unlink (remAuthFile);
 
@@ -697,7 +707,6 @@ void CompletNewConnectionMsg(void)
 {
 	flist *l = pending_ice_conn_list;
 	FIceConn ice_conn;
-	Bool pending = False;
 	FIceAcceptStatus cstatus;
 
 	if (!SessionSupport)
@@ -711,7 +720,6 @@ void CompletNewConnectionMsg(void)
 		cstatus = FIceConnectionStatus(ice_conn);
 		if (cstatus == (int)FIceConnectPending)
 		{
-			pending = True;
 			l = l->next;
 		}
 		else if (cstatus == (int)FIceConnectAccepted)
