@@ -753,7 +753,7 @@ static Binding *ParseKeyEntry(char *tline)
 
   XDisplayKeycodes(theDisplay, &min, &max);
   for (i=min; i<=max; i++) {
-    if (XKeycodeToKeysym(theDisplay, i, 0) == keysym) {
+    if (fvwm_KeycodeToKeysym(theDisplay, i, 0, 0) == keysym) {
       if (!func) {
 	func = parse_function_list(action);
 	if (!func) {
@@ -1147,11 +1147,9 @@ static void handle_button_config(int manager, int context, char *option)
 static void add_weighted_sort(WinManager *man, WeightedSort *weighted_sort)
 {
 	WeightedSort *p;
-	int i;
 
 	if (man->weighted_sorts_len == man->weighted_sorts_size)
 	{
-		i = man->weighted_sorts_size;
 		man->weighted_sorts_size += 16;
 		man->weighted_sorts = (WeightedSort *)saferealloc(
 			(char *)man->weighted_sorts,
@@ -1418,7 +1416,7 @@ void read_in_resources(void)
 	  continue;
 	}
 	do {
-	  ConsoleDebug(CONFIG, "dont show: %s\n", token);
+	  ConsoleDebug(CONFIG, "don't show: %s\n", token);
 	  if (manager == -1) {
 	    int i;
 	    for (i = 0; i < globals.num_managers; i++)
@@ -1890,6 +1888,9 @@ void read_in_resources(void)
       else if (!strcasecmp(option1, "iconButton")) {
 	handle_button_config(manager, ICON_CONTEXT, option1);
       }
+      else if (!strcasecmp(option1, "iconandselectButton")) {
+	handle_button_config(manager, ICON_SELECT_CONTEXT, option1);
+      }
       else if (!strcasecmp(option1, "plainButton")) {
 	handle_button_config(manager, PLAIN_CONTEXT, option1);
       }
@@ -1989,6 +1990,20 @@ void read_in_resources(void)
 	SET_MANAGER(manager, colorsets[ICON_CONTEXT], n);
 	AllocColorset(n);
       }
+      else if (!strcasecmp(option1, "iconandselectcolorset")) {
+	p = read_next_cmd(READ_ARG);
+	if (!p) {
+	  ConsoleMessage("Bad line: %s\n", current_line);
+	  continue;
+	}
+	if (extract_int(p, &n) == 0) {
+	  ConsoleMessage("This is not a number: %s\n", p);
+	  ConsoleMessage("Bad line: %s\n", current_line);
+	  continue;
+	}
+	SET_MANAGER(manager, colorsets[ICON_SELECT_CONTEXT], n);
+	AllocColorset(n);
+      }
       else if (!strcasecmp(option1, "usewinlist")) {
 	p = read_next_cmd(READ_ARG);
 	if (!p) {
