@@ -110,9 +110,11 @@ static int InfEq(char *arg1,char *arg2)
 
 static int Equal(char *arg1,char *arg2)
 {
-  int an1,an2;
-  an1=atoi(arg1);
-  an2=atoi(arg2);
+  int n;
+
+  n = atoi(arg1);
+  n = atoi(arg2);
+  (void)n;
   return (strcmp(arg1,arg2)==0);
 }
 
@@ -134,9 +136,11 @@ static int Sup(char *arg1,char *arg2)
 
 static int Diff(char *arg1,char *arg2)
 {
-  int an1,an2;
-  an1=atoi(arg1);
-  an2=atoi(arg2);
+  int n;
+
+  n = atoi(arg1);
+  n = atoi(arg2);
+  (void)n;
   return (strcmp(arg1,arg2)!=0);
 }
 
@@ -326,7 +330,6 @@ static char *FuncGetOutput(int *NbArg, long *TabArg)
   int line,index,i=2,j=0,k,NewWord;
   FILE *f;
   int maxsize=32000;
-  int size;
 
   (*NbArg)++;
   cmndbuf=CalcArg(TabArg,NbArg);
@@ -350,10 +353,13 @@ static char *FuncGetOutput(int *NbArg, long *TabArg)
     }
     else
     {
+      int n;
+
       if (strcmp(Command,"None"))
 	free(BufCom);
       BufCom = (char*)safecalloc(sizeof(char),maxsize);
-      size = fread(BufCom,1,maxsize,f);
+      n = fread(BufCom,1,maxsize,f);
+      (void)n;
       pclose(f);
       strncpy(Command,cmndbuf,255);
       TimeCom=time(NULL);
@@ -623,12 +629,17 @@ static char *LaunchScript (int *NbArg,long *TabArg)
   free(arg);
 
   /* Envoi de la commande */
-  write(fd[0], &ref, sizeof(Window));
-  leng = strlen(execstr);
-  write(fd[0], &leng, sizeof(unsigned long));
-  write(fd[0], execstr, leng);
-  leng = 1;
-  write(fd[0], &leng, sizeof(unsigned long));
+  {
+    int n;
+
+    n = write(fd[0], &ref, sizeof(Window));
+    (void)n;
+    leng = strlen(execstr);
+    n = write(fd[0], &leng, sizeof(unsigned long));
+    n = write(fd[0], execstr, leng);
+    leng = 1;
+    n = write(fd[0], &leng, sizeof(unsigned long));
+  }
   free(execstr);
 
   /* Retourne l'id du fils */
@@ -872,8 +883,11 @@ static char *FuncSendMsgAndGet(int *NbArg,long *TabArg)
     {
       if ((f = fopen (out_fifo, "r")) != NULL)
       {
+	int n;
+
 	buf=(char*)safecalloc(sizeof(char),maxsize);
-	fread(buf,1,maxsize,f);
+	n = fread(buf,1,maxsize,f);
+	(void)n;
 	fclose (f);
       }
       else
@@ -1017,12 +1031,17 @@ static void Exec (int NbArg,long *TabArg)
     free(tempstr);
   }
 
-  write(fd[0], &ref, sizeof(Window));
-  leng = strlen(execstr);
-  write(fd[0], &leng, sizeof(unsigned long));
-  write(fd[0], execstr, leng);
-  leng = 1;
-  write(fd[0], &leng, sizeof(unsigned long));
+  {
+    int n;
+
+    n = write(fd[0], &ref, sizeof(Window));
+    (void)n;
+    leng = strlen(execstr);
+    n = write(fd[0], &leng, sizeof(unsigned long));
+    n = write(fd[0], execstr, leng);
+    leng = 1;
+    n = write(fd[0], &leng, sizeof(unsigned long));
+  }
   free(execstr);
 }
 
@@ -1453,7 +1472,7 @@ static void ChangeWindowTitle(int NbArg,long * TabArg){
 static void ChangeWindowTitleFromArg(int NbArg,long * TabArg){
 
   char *arg;
-  int argVal;  
+  int argVal;
   int tmpVal=NbArg-1;
 
   arg=CalcArg(TabArg,&tmpVal);
@@ -1581,14 +1600,12 @@ static void IfThen (int NbArg,long *TabArg)
 /* Instruction boucle **/
 static void Loop (int NbArg,long *TabArg)
 {
-  int IdVar;
   char *arg[2];
   int limit[2];
   int i;
   int CurrArg=0;
 
   /* le premier argument est une variable */
-  IdVar = TabArg[0];
   /*On ajuste la taille de la var pour contenir un nombre */
   TabVVar[TabArg[0]] = (char*)saferealloc(TabVVar[TabArg[0]],sizeof(char)*10);
   /* Calcul des 2 autres arguments */
